ChromaFormat

Enum ChromaFormat 

pub enum ChromaFormat {
    Monochrome,
    Yuv420,
    Yuv422,
    Yuv444,
}
Chroma subsampling mode.

Variants



Monochrome

4:0:0 — monochrome (luma only, no chroma). ChromaArrayType = 0.



Yuv420

4:2:0 — chroma is half width, half height. ChromaArrayType = 1.



Yuv422

4:2:2 — chroma is half width, full height. ChromaArrayType = 2.



Yuv444

4:4:4 — chroma is full width, full height. ChromaArrayType = 3.

Implementations

Source

impl ChromaFormat

pub fn idc(self) -> u32

chroma_format_idc value written in the SPS (HEVC Table 6-1).

pub fn is_monochrome(self) -> bool

True when there is no chroma (4:0:0).

pub fn sub_w(self) -> usize

Horizontal subsampling factor: luma_width / chroma_width. (1 for monochrome, which has no chroma; the value is unused but kept well-defined.)

pub fn sub_h(self) -> usize

Vertical subsampling factor: luma_height / chroma_height.

pub fn chroma_tb_size(self) -> usize

Side length of each chroma transform block for an 8×8 luma CU.

pub fn chroma_tbs_per_cu(self) -> usize

Number of chroma transform blocks stacked vertically per 8×8 luma CU.